function love.load()
	love.filesystem.setIdentity("colorpix")
	love.graphics.setBackgroundColor(230,230,250)
	local f = love.graphics.newFont(15)
	love.graphics.setFont(f)
	love.graphics.setLineWidth(2)
	
	pixels = 15 -- how many colored pixels, def. 15
	pixelsize = 25 -- size of one pixel, def. 25
	
	turns_max= 25
	difficulty = "Easy"

	turns=0
	gamesaved=0 --need this to check if game is saved
	
	gameover=0
	pixelcnt=0

	math.randomseed(os.time()) -- use ostime for initial random seed
	fill_rnd() -- fill board


	welcomescreen = true
    
end

function load_score()
	if difficulty == "Easy" then
		if love.filesystem.exists("colorpix_e.txt") then
			return(love.filesystem.read( "colorpix_e.txt"))
		else
			love.filesystem.newFile( "colorpix_e.txt" )
			love.filesystem.write("colorpix_e.txt", 35)
			return 35
		end
	elseif difficulty == "Hard" then
		if love.filesystem.exists("colorpix_h.txt") then
			return(love.filesystem.read( "colorpix_h.txt"))
		else
			love.filesystem.newFile( "colorpix_h.txt" )
			love.filesystem.write("colorpix_h.txt", 25)
			return 25
		end	
	end
end

function save_score(score)
	if difficulty == "Easy" then 
		love.filesystem.write("colorpix_e.txt", score)
	elseif difficulty == "Hard" then
		love.filesystem.write("colorpix_h.txt", score)
	end
	
	gamesaved=1
	return(0)
end
	

function fill_rnd()
	board ={}
	for i=1,pixels do
		board[i] = {} -- create new row
		for j=1,pixels do
			board[i][j] = math.random(0,5)
		end
	end
	oldcolor = board[1][1]
	gameover=0
	gamesaved=0
	turns=0
	pixelcnt=0
	return(0)
end --end fill_rnd()

function inrange( num, min, max )
	return (num >= min and num <= max)
end


function check( x,y, oldcolor, newcolor ) --wikipedia: flood fill ;)
	-- RECURSIVE EDITION:
	--if board[x][y] ~= oldcolor then return end
	--board[x][y] = newcolor
	
	--if x > 1 then check(x-1,y,oldcolor,newcolor) end
	--if y > 1 then check(x,y-1,oldcolor,newcolor) end
	--if x < pixels then check(x+1,y,oldcolor,newcolor) end
	--if y < pixels then check(x,y+1,oldcolor,newcolor) end
	if oldcolor==newcolor then return end -- endlessloop if forgotten
	tb = {}
	table.insert(tb, {x,y})
	for i,v in pairs(tb) do
		x=v[1]
		y=v[2]
		if board[x][y] == oldcolor then
			board[x][y] = newcolor
			if x>1 then table.insert(tb,{x-1,y}) end
			if y>1 then table.insert(tb,{x,y-1}) end
			if x<pixels then table.insert(tb,{x+1,y}) end
			if y<pixels then table.insert(tb,{x,y+1}) end			
		end
	end

	--check if game finished
	pixelcnt=0
	for i=1,pixels do
		for j=1,pixels do
		if board[i][j]==newcolor then pixelcnt = pixelcnt+1 end
		end
	end
	return(0)
end





function love.mousepressed(x, y, button)
	if(welcomescreen) then
		if button == 'l' then
			if inrange(x, 192,292 ) and inrange(y, 200, 240 ) then
				turns_max = 35
				difficulty = "Easy"
				highscore=tonumber(load_score())
				welcomescreen = false
			end
			if inrange(x, 312, 412) and inrange(y, 200, 240 ) then
				turns_max = 25
				difficulty = "Hard"
				highscore=tonumber(load_score())
				welcomescreen = false
			end
		end
	else
	   if button == 'l' then
		if inrange(x,440,480) and inrange(y,25,65) and gameover==0 then 
			if not(oldcolor == 0) then turns=turns+1 check(1,1,oldcolor,0) oldcolor=0 end
		end --check blue button
		if inrange(x,490,530) and inrange(y,25,65) and gameover==0 then 
			if not(oldcolor == 1) then turns=turns+1 check(1,1,oldcolor,1) oldcolor=1 end -- pink
		end
		if inrange(x,540,580) and inrange(y,25,65) and gameover==0 then 
			if not(oldcolor == 2) then turns=turns+1 check(1,1,oldcolor,2) oldcolor=2 end -- violet
		end
		if inrange(x,440,480) and inrange(y,75,115) and gameover==0 then 
			if not(oldcolor == 3) then turns=turns+1 check(1,1,oldcolor,3) oldcolor=3 end -- green
		end
		if inrange(x,490,530) and inrange(y,75,115) and gameover==0 then 
			if not(oldcolor == 4) then turns=turns+1 check(1,1,oldcolor,4) oldcolor=4 end -- yellow
		end
		if inrange(x,540,580) and inrange(y,75,115) and gameover==0 then 
			if not(oldcolor == 5) then turns=turns+1 check(1,1,oldcolor,5) oldcolor=5 end -- red
		end
		if inrange(x,480,580) and inrange(y,360,400) then 
			welcomescreen = true
			fill_rnd()  
		end -- new game button
	   end
	  
		if turns == turns_max then gameover=1 end
	end
end -- end mousepressed

function love.draw()	
	
		if(welcomescreen) then
			-- Background fill with colored blocks.
			for w=0, 605 / 40 do
				for h=0, 420 / 40 do
					local c = math.random(0,5)
					if c == 0 then  love.graphics.setColor(97,187,217) love.graphics.rectangle('fill', w*40,h*40,40,40) end
					if c == 1 then  love.graphics.setColor(246,100,138) love.graphics.rectangle('fill', w*40,h*40,40,40) end
					if c == 2 then  love.graphics.setColor(160,32,240) love.graphics.rectangle('fill', w*40,h*40,40,40) end
					if c == 3 then  love.graphics.setColor(73,211,73) love.graphics.rectangle('fill', w*40,h*40,40,40) end
					if c == 4 then  love.graphics.setColor(255,245,94) love.graphics.rectangle('fill', w*40,h*40,40,40) end
					if c == 5 then  love.graphics.setColor(255,245,94) love.graphics.rectangle('fill', w*40,h*40,40,40) end
				end
			end
		
			-- Draws our black-bordered white box around our
			-- difficulty selection
			love.graphics.setColor(0,0,0)
			love.graphics.rectangle('fill', 115, 0, 360+10, 420)
				
			love.graphics.setColor(255,255,255) -- white
			love.graphics.rectangle('fill', 120, 0, 360, 420)
			
			love.graphics.setColor(0,0,0) -- black
			love.graphics.print("Welcome to Colorpix", 220,100)
			love.graphics.rectangle('line', 192, 200, 100,40 )
			love.graphics.rectangle('line', 312, 200, 100,40 )
			love.graphics.print("Easy", 225, 225)
			love.graphics.print("Hard", 345, 225)
			
		else
			--draw menu
			love.graphics.setColor(97,187,217) -- blue
			love.graphics.rectangle('fill', 440, 25, 40, 40)
			love.graphics.setColor(246,100,138) -- pink
			love.graphics.rectangle('fill', 490, 25, 40, 40)
			love.graphics.setColor(160,32,240)  -- violet
			love.graphics.rectangle('fill', 540, 25, 40, 40)
			love.graphics.setColor(73,211,73)  -- green
			love.graphics.rectangle('fill', 440, 75, 40, 40)
			love.graphics.setColor(255,245,94)  -- yellow
			love.graphics.rectangle('fill', 490, 75, 40, 40)
			love.graphics.setColor(252,62,52)  -- red
			love.graphics.rectangle('fill', 540, 75, 40, 40)

			love.graphics.setColor(0,0,0)  -- black for turns
			love.graphics.print("Difficulty: " .. difficulty, 440, 150)
			love.graphics.print("Turns: " .. turns .. "/" .. turns_max, 440, 178)
			love.graphics.print("Highscore: " .. highscore,440,206) --highscore
			if gameover==1 and pixelcnt~=pixels*pixels then love.graphics.print("Game Over",440,234) end --game over 
			if pixelcnt==pixels*pixels then -- game won
				love.graphics.print("Game Won!",440,234)
				if gamesaved == 0 then
					if turns<highscore then save_score(turns) highscore=turns end			
					end
			end 
			
			love.graphics.rectangle("line", 480, 360, 100, 40) -- new game button
			love.graphics.print("New Game",490,385)
			
			
		

		for i=1,pixels do
			for j=1,pixels do
				if (board[i][j]) == 0 then love.graphics.setColor(97,187,217) end -- blue
				if (board[i][j]) == 1 then love.graphics.setColor(246,100,138) end -- pink
				if (board[i][j]) == 2 then love.graphics.setColor(160,32,240) end -- violet
				if (board[i][j]) == 3 then love.graphics.setColor(73,211,73) end -- green
				if (board[i][j]) == 4 then love.graphics.setColor(255,245,94) end -- yellow
				if (board[i][j]) == 5 then love.graphics.setColor(252,62,52) end -- red
				
				love.graphics.rectangle('fill', i*pixelsize, j*pixelsize, pixelsize, pixelsize)
				
			end
		end
	end	   
end --end draw

